exteriorMatch-package:
\Sexpr[results=rd,stage=build]{tools:::Rd_package_title("#1")}exteriorMatchConstructs the Exterior Match from Two Matched Control Groups
Description
\Sexpr[results=rd,stage=build]{tools:::Rd_package_description("#1")}exteriorMatchIf one treated group is matched to one control reservoir in two different ways to produce two sets of treated-control matched pairs, then the two control groups may be entwined, in the sense that some control individuals are in both control groups. The exterior match is used to compare the two control groups.
Arguments
Details
The DESCRIPTION file:
\Sexpr[results=rd,stage=build]{tools:::Rd_package_DESCRIPTION("#1")}exteriorMatchThis package was not yet installed at build time.
\Sexpr[results=rd,stage=build]{tools:::Rd_package_indices("#1")}exteriorMatch
Index: This package was not yet installed at build time.
References
Rosenbaum, P.R. and Silber, J.H., 2013. Using the exterior match to compare
two entwined matched control groups. The American Statistician, 67(2), pp.67-75.